package com.usky.system.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.common.core.constants.Constants;
import com.usky.common.core.util.StringUtils;
import com.usky.common.security.utils.SecurityUtils;
import com.usky.system.controller.web.SysMenuController;
import com.usky.system.domain.SysMenu;
import com.usky.system.domain.SysMobileMenu;
import com.usky.system.domain.SysMobileTenantMenu;
import com.usky.system.domain.constants.UserConstants;
import com.usky.system.mapper.SysMobileMenuMapper;
import com.usky.system.service.SysMobileMenuService;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.system.service.SysMobileTenantMenuService;
import com.usky.system.service.vo.MetaVo;
import com.usky.system.service.vo.RouterVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

/**
 * <p>
 * 移动端_菜单权限表 服务实现类
 * </p>
 *
 * @author JCB
 * @since 2022-08-11
 */
@Service
public class SysMobileMenuServiceImpl extends AbstractCrudService<SysMobileMenuMapper, SysMobileMenu> implements SysMobileMenuService {

    @Autowired
    private SysMobileTenantMenuService sysMobileTenantMenuService;

    @Override
    public List<SysMobileMenu> moveRoute(){
        List<SysMobileMenu> list = new ArrayList<>();
        LambdaQueryWrapper<SysMobileTenantMenu> query = Wrappers.lambdaQuery();
        query.eq(SysMobileTenantMenu::getTenantId, SecurityUtils.getTenantId());
        List<SysMobileTenantMenu> tenantMenuList = sysMobileTenantMenuService.list(query);
        if (CollectionUtils.isNotEmpty(tenantMenuList)){
            List<Long> menuIdList = new ArrayList<>();
            for (int i = 0; i < tenantMenuList.size(); i++) {
                menuIdList.add(tenantMenuList.get(i).getMenuId());
            }
            LambdaQueryWrapper<SysMobileMenu> queryOne = Wrappers.lambdaQuery();
            queryOne.in(SysMobileMenu::getMenuId, menuIdList)
                    .eq(SysMobileMenu::getVisible,0)
                    .eq(SysMobileMenu::getStatus,0);
            queryOne.orderByAsc(SysMobileMenu::getOrderNum);
            List<SysMobileMenu> menuList = this.list(queryOne);
            list = getChildPerms(menuList, 0);
        }
        return list;
    }

    /**
     * 根据父节点的ID获取所有子节点
     *
     * @param list 分类表
     * @param parentId 传入的父节点ID
     * @return String
     */
    public List<SysMobileMenu> getChildPerms(List<SysMobileMenu> list, int parentId)
    {
        List<SysMobileMenu> returnList = new ArrayList<SysMobileMenu>();
        for (Iterator<SysMobileMenu> iterator = list.iterator(); iterator.hasNext();)
        {
            SysMobileMenu t = (SysMobileMenu) iterator.next();
            // 一、根据传入的某个父节点ID,遍历该父节点的所有子节点
            if (t.getParentId() == parentId)
            {
                recursionFn(list, t);
                returnList.add(t);
            }
        }
        return returnList;
    }


    /**
     * 递归列表
     *
     * @param list
     * @param t
     */
    private void recursionFn(List<SysMobileMenu> list, SysMobileMenu t)
    {
        // 得到子节点列表
        List<SysMobileMenu> childList = getChildList(list, t);
        t.setChildren(childList);
        for (SysMobileMenu tChild : childList)
        {
            if (hasChild(list, tChild))
            {
                recursionFn(list, tChild);
            }
        }
    }

    /**
     * 得到子节点列表
     */
    private List<SysMobileMenu> getChildList(List<SysMobileMenu> list, SysMobileMenu t)
    {
        List<SysMobileMenu> tlist = new ArrayList<SysMobileMenu>();
        Iterator<SysMobileMenu> it = list.iterator();
        while (it.hasNext())
        {
            SysMobileMenu n = (SysMobileMenu) it.next();
            if (n.getParentId().longValue() == t.getMenuId().longValue())
            {
                tlist.add(n);
            }
        }
        return tlist;
    }

    /**
     * 判断是否有子节点
     */
    private boolean hasChild(List<SysMobileMenu> list, SysMobileMenu t)
    {
        return getChildList(list, t).size() > 0 ? true : false;
    }

}
